// page-cart.ts
import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

interface BanquetHall {
  id: number;
  name: string;
  subtitle: string;
  area: string;
  minTables: number;
  maxTables: number;
  mealPrice: number;
  hallPrice: number;
  areaSize: number;
  imageUrl: string;
  height: string;
  originalPrice?: number;
  featured?: boolean;
  available: boolean;
}

interface FilterOption {
  value: string;
  label: string;
}

@Component({
  selector: 'app-page-cart',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './page-cart.html',
  styleUrls: ['./page-cart.scss']
})
export class PageCart {
  // 筛选选项
  areas: string[] = ['姑苏区', '工业园区', '高新区', '吴中区', '相城区'];
  tableRanges: FilterOption[] = [
    { value: '0-20', label: '20桌以下' },
    { value: '20-40', label: '20-40桌' },
    { value: '40-60', label: '40-60桌' },
    { value: '60+', label: '60桌以上' }
  ];
  mealPrices: FilterOption[] = [
    { value: '1000-1999', label: '1000-1999元' },
    { value: '2000-2999', label: '2000-2999元' },
    { value: '3000-3999', label: '3000-3999元' },
    { value: '4000+', label: '4000元以上' }
  ];
  sortOptions: FilterOption[] = [
    { value: 'price-low', label: '价格从低到高' },
    { value: 'price-high', label: '价格从高到低' },
    { value: 'area-high', label: '面积从大到小' },
    { value: 'tables-high', label: '容纳桌数从多到少' }
  ];
  
  // 当前筛选状态
  selectedArea: string = 'all';
  selectedTableRange: string = 'all';
  selectedMealPrice: string = 'all';
  selectedSort: string = 'default';
  searchQuery: string = '';
  showSearch: boolean = false;
  
  // 通知状态
  hasNotification: boolean = true;
  
  // 宴会厅数据
  halls: BanquetHall[] = [
    {
      id: 1,
      name: 'LUXURS 苏州庄',
      subtitle: '古典与现代完美融合',
      area: '姑苏区',
      minTables: 45,
      maxTables: 60,
      mealPrice: 1999,
      hallPrice: 456888,
      areaSize: 728,
      imageUrl: 'https://images.unsplash.com/photo-1511795409834-ef04bbd61622?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&q=80',
      height: '4.5',
      featured: true,
      available: true
    },
    {
      id: 2,
      name: 'OSCARS 奥斯卡',
      subtitle: '欧式奢华宴会厅',
      area: '工业园区',
      minTables: 30,
      maxTables: 40,
      mealPrice: 1999,
      hallPrice: 388800,
      areaSize: 500,
      imageUrl: 'https://images.unsplash.com/photo-1566665797739-1674de7a421a?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&q=80',
      height: '4.5',
      available: true
    },
    {
      id: 3,
      name: 'SHARRY 星空之镜',
      subtitle: '梦幻星空主题宴会厅',
      area: '高新区',
      minTables: 25,
      maxTables: 35,
      mealPrice: 1999,
      hallPrice: 229999,
      areaSize: 428,
      imageUrl: 'https://images.unsplash.com/photo-1519671482749-fd09be7ccebf?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&q=80',
      height: '4.5',
      originalPrice: 289999,
      featured: true,
      available: false
    },
    {
      id: 4,
      name: 'GRAND HALL 盛世厅',
      subtitle: '豪华宴会与会议空间',
      area: '姑苏区',
      minTables: 60,
      maxTables: 80,
      mealPrice: 2999,
      hallPrice: 528000,
      areaSize: 950,
      imageUrl: 'https://images.unsplash.com/photo-1552168324-d612d77725e3?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&q=80',
      height: '5.2',
      available: true
    },
    {
      id: 5,
      name: 'AURORA 极光厅',
      subtitle: '未来科技感宴会空间',
      area: '工业园区',
      minTables: 35,
      maxTables: 50,
      mealPrice: 3599,
      hallPrice: 398000,
      areaSize: 680,
      imageUrl: 'https://images.unsplash.com/photo-1527525443983-6e60c75fff46?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&q=80',
      height: '5.5',
      featured: true,
      available: true
    },
    {
      id: 6,
      name: 'CRYSTAL 水晶宫',
      subtitle: '透明穹顶自然采光',
      area: '吴中区',
      minTables: 20,
      maxTables: 30,
      mealPrice: 2599,
      hallPrice: 298000,
      areaSize: 380,
      imageUrl: 'https://images.unsplash.com/photo-1519643381401-22c77e60520e?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&q=80',
      height: '6.0',
      available: true
    }
  ];
  
  // 过滤后的宴会厅列表
  filteredHalls: BanquetHall[] = [];
  
  // 加载状态
  isLoading: boolean = false;
  
  // 当前悬停的宴会厅ID
  hoveredHall: number | null = null;
  
  ngOnInit() {
    // 初始化时加载所有宴会厅
    this.filteredHalls = [...this.halls];
  }
  
  // 切换搜索框显示
  toggleSearch() {
    this.showSearch = !this.showSearch;
    if (this.showSearch) {
      setTimeout(() => {
        const searchInput = document.querySelector('.search-bar input') as HTMLInputElement;
        if (searchInput) searchInput.focus();
      }, 100);
    }
  }
  
  // 筛选和排序宴会厅
  filterHalls() {
    this.isLoading = true;
    
    // 模拟API请求延迟
    setTimeout(() => {
      let result = [...this.halls];
      
      // 区域筛选
      if (this.selectedArea !== 'all') {
        result = result.filter(hall => hall.area === this.selectedArea);
      }
      
      // 容纳桌数筛选
      if (this.selectedTableRange !== 'all') {
        if (this.selectedTableRange === '0-20') {
          result = result.filter(hall => hall.maxTables <= 20);
        } else if (this.selectedTableRange === '20-40') {
          result = result.filter(hall => 
            hall.minTables >= 20 && hall.maxTables <= 40
          );
        } else if (this.selectedTableRange === '40-60') {
          result = result.filter(hall => 
            hall.minTables >= 40 && hall.maxTables <= 60
          );
        } else if (this.selectedTableRange === '60+') {
          result = result.filter(hall => hall.minTables >= 60);
        }
      }
      
      // 餐标范围筛选
      if (this.selectedMealPrice !== 'all') {
        if (this.selectedMealPrice === '1000-1999') {
          result = result.filter(hall => 
            hall.mealPrice >= 1000 && hall.mealPrice <= 1999
          );
        } else if (this.selectedMealPrice === '2000-2999') {
          result = result.filter(hall => 
            hall.mealPrice >= 2000 && hall.mealPrice <= 2999
          );
        } else if (this.selectedMealPrice === '3000-3999') {
          result = result.filter(hall => 
            hall.mealPrice >= 3000 && hall.mealPrice <= 3999
          );
        } else if (this.selectedMealPrice === '4000+') {
          result = result.filter(hall => hall.mealPrice >= 4000);
        }
      }
      
      // 搜索筛选
      if (this.searchQuery) {
        const query = this.searchQuery.toLowerCase();
        result = result.filter(hall => 
          hall.name.toLowerCase().includes(query) || 
          hall.subtitle.toLowerCase().includes(query) ||
          hall.area.toLowerCase().includes(query)
        );
      }
      
      // 排序
      if (this.selectedSort !== 'default') {
        result.sort((a, b) => {
          if (this.selectedSort === 'price-low') {
            return a.hallPrice - b.hallPrice;
          } else if (this.selectedSort === 'price-high') {
            return b.hallPrice - a.hallPrice;
          } else if (this.selectedSort === 'area-high') {
            return b.areaSize - a.areaSize;
          } else if (this.selectedSort === 'tables-high') {
            return b.maxTables - a.maxTables;
          }
          return 0;
        });
      }
      
      this.filteredHalls = result;
      this.isLoading = false;
    }, 600); // 模拟加载时间
  }
  
  // 重置筛选条件
  resetFilters() {
    this.selectedArea = 'all';
    this.selectedTableRange = 'all';
    this.selectedMealPrice = 'all';
    this.selectedSort = 'default';
    this.searchQuery = '';
    this.filterHalls();
  }
  
  // 返回上一级
  goBack() {
    console.log('返回上一级页面');
    // 实际项目中这里应该是路由导航
  }
  
  // 新增宴会厅
  addNewBanquet() {
    console.log('打开新增宴会厅表单');
    // 实际项目中这里应该打开模态框或导航到创建页面
  }
  
  // 预订宴会厅
  bookHall(hall: BanquetHall) {
    if (hall.available) {
      console.log(`开始预订: ${hall.name} 宴会厅`);
      // 实际项目中这里应该打开预订表单
    }
  }
  
  // 查看详情
  showDetails(hall: BanquetHall) {
    console.log(`查看 ${hall.name} 的详细信息`);
    // 实际项目中这里应该导航到详情页面
  }
  
  // 卡片悬停效果
  hoverCard(hall: BanquetHall, isHover: boolean) {
    this.hoveredHall = isHover ? hall.id : null;
  }
}